@@ -23,7 +23,7 @@ has '+to_html_xslt_transform_basename' =>
     (default => 'fortune-xml-to-html.xslt');
 
 has '_mode' => (is => 'rw', init_arg => 'mode');
-has '_output_mode' => (is => 'rw');
+has '_output_mode' => (is => 'rw', init_arg => 'output_mode',);
 
 =head1 NAME
 
@@ -31,11 +31,11 @@ XML::Grammar::Fortune - convert the FortunesXML grammar to other formats and fro
 
 =head1 VERSION
 
-Version 0.0504
+Version 0.0505
 
 =cut
 
-our $VERSION = '0.0504';
+our $VERSION = '0.0505';
 
 
 =head1 SYNOPSIS
@@ -73,9 +73,9 @@ our $VERSION = '0.0504';
 
 =head1 FUNCTIONS
 
-=head2 my $processor = XML::Grammar::Fortune->new({mode => $mode, input => $in, output => $out});
+=head2 my $processor = XML::Grammar::Fortune->new({mode => $mode, input => $in, output => $out, output_mode => "string",});
 
-Creates a new processor with mode $mode, and input and output files.
+Creates a new processor with mode $mode, output_mode "string", and input and output files.
 
 =head2 $self->run({ %args})
 
